pub enum StringLengthLocale {
MinLength(usize),
MaxLength(usize),
}Expand description
An enumeration representing the constraints for string length, either specifying a minimum length or a maximum length.
Variants
-
MinLength(usize)Specifies the minimum length that a string is allowed to have. Theusizerepresents the minimum number of characters required. -
MaxLength(usize)Specifies the maximum length that a string is allowed to have. Theusizerepresents the maximum number of characters allowed.
Variants